import React from "react";
import { View } from "react-native";
import { nodeFromRef } from "react-native-shared-element";
import SceneContext from "./SceneContext";
import withStage from "./withStage";
export class SceneClass extends React.Component {
    constructor() {
        super(...arguments);
        this._ancestorNode = undefined;
        this._actors = {};
        this.onSetRef = (ref) => {
            this.setAncestor(nodeFromRef(ref));
        };
    }
    componentDidMount() {
        const { sceneId, stage } = this.props;
        this._sceneId = sceneId;
        if (this._sceneId) {
            stage.addScene(this._sceneId, this);
        }
    }
    componentDidUpdate() {
        const { sceneId, stage } = this.props;
        if (this._sceneId !== sceneId) {
            if (this._sceneId) {
                stage.removeScene(this._sceneId);
            }
            this._sceneId = sceneId;
            if (this._sceneId) {
                stage.addScene(this._sceneId, this);
            }
        }
    }
    componentWillUnmount() {
        if (this._sceneId) {
            this.props.stage.removeScene(this._sceneId);
        }
    }
    getAncestor() {
        return this._ancestorNode;
    }
    setAncestor(ancestorNode) {
        if (this._ancestorNode === ancestorNode)
            return;
        this._ancestorNode = ancestorNode || undefined;
    }
    addActor(id, actor) {
        this._actors[id] = actor;
    }
    removeActor(id) {
        delete this._actors[id];
    }
    getActors() {
        return this._actors;
    }
    render() {
        return (<SceneContext.Provider value={this}>
        <View ref={this.onSetRef} pointerEvents={"box-none"} {...this.props}/>
      </SceneContext.Provider>);
    }
}
export default withStage(SceneClass);
//# sourceMappingURL=Scene.js.map