import React from "react";
import { EventEmitter } from "events";
import StageContext from "./StageContext";
export default class Stage extends React.Component {
    constructor() {
        super(...arguments);
        this._scenes = {};
        this._ee = new EventEmitter();
    }
    addScene(id, scene) {
        this._scenes[id] = scene;
        this._ee.emit(`add:${id}`, id, scene);
    }
    removeScene(id) {
        delete this._scenes[id];
        this._ee.emit(`remove:${id}`, id);
    }
    getScene(id) {
        return this._scenes[id];
    }
    onAddScene(id, handler) {
        this._ee.on(`add:${id}`, handler);
    }
    removeAddSceneListener(id, handler) {
        this._ee.removeListener(`add:${id}`, handler);
    }
    onRemoveScene(id, handler) {
        this._ee.on(`remove:${id}`, handler);
    }
    removeRemoveSceneListener(id, handler) {
        this._ee.removeListener(`remove:${id}`, handler);
    }
    render() {
        return <StageContext.Provider value={this} {...this.props}/>;
    }
}
//# sourceMappingURL=Stage.js.map