import Animated from "react-native-reanimated";
import { Animation, SpringDriver } from "@tleef/react-native-reanimated-utils/lib";
export default class Transition {
    constructor(fromId, toId, springConfig, stage, onReady, onFinish) {
        this.continue = () => {
            this._animation.continue();
        };
        this.cancel = () => {
            this._animation.cancel();
        };
        this.onEnterStart = (handler) => {
            this._animation.onEnterStart(handler);
        };
        this.onEnterEnd = (handler) => {
            this._animation.onEnterEnd(handler);
        };
        this.onLeaveStart = (handler) => {
            this._animation.onLeaveStart(handler);
        };
        this.onLeaveEnd = (handler) => {
            this._animation.onLeaveEnd(handler);
        };
        this._handleAnimationEnd = (cancelled) => {
            if (!cancelled) {
                this._handleFinished(this);
            }
        };
        this._handleAddScene = (sceneId, scene) => {
            if (this._fromId === sceneId) {
                this._fromScene = scene;
            }
            else if (this._toId === sceneId) {
                this._toScene = scene;
            }
            this._stage.removeAddSceneListener(sceneId, this._handleAddScene);
            if (this._fromScene && this._toScene) {
                this._handleReady(this);
            }
        };
        const defaultSpringConfig = Animated.SpringUtils.makeDefaultConfig();
        const springDriver = new SpringDriver({
            stiffness: springConfig.stiffness || defaultSpringConfig.stiffness,
            mass: springConfig.mass || defaultSpringConfig.mass,
            damping: springConfig.damping || defaultSpringConfig.damping,
            overshootClamping: springConfig.overshootClamping || defaultSpringConfig.overshootClamping,
            restDisplacementThreshold: springConfig.restDisplacementThreshold ||
                defaultSpringConfig.restDisplacementThreshold,
            restSpeedThreshold: springConfig.restSpeedThreshold ||
                defaultSpringConfig.restSpeedThreshold
        });
        this._key = Transition.keyFor(fromId, toId);
        this._fromId = fromId;
        this._toId = toId;
        this._animation = new Animation(springDriver);
        this._stage = stage;
        this._handleReady = onReady;
        this._handleFinished = onFinish;
        this._fromScene = stage.getScene(fromId);
        this._toScene = stage.getScene(toId);
        if (!this._fromScene) {
            stage.onAddScene(fromId, this._handleAddScene);
        }
        if (!this._toScene) {
            stage.onAddScene(toId, this._handleAddScene);
        }
        this._animation.onEnterEnd(this._handleAnimationEnd);
        this._animation.onLeaveEnd(this._handleAnimationEnd);
        if (this._fromScene && this._toScene) {
            this._handleReady(this);
        }
    }
    get key() {
        return this._key;
    }
    get fromId() {
        return this._fromId;
    }
    get toId() {
        return this._toId;
    }
    get fromScene() {
        return this._fromScene;
    }
    get toScene() {
        return this._toScene;
    }
    get animValue() {
        return this._animation.value;
    }
    get animate() {
        return this._animation.animate;
    }
    static keyFor(fromId, toId) {
        return `${fromId}->${toId}`;
    }
}
//# sourceMappingURL=Transition.js.map